==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/automation/kotlin/inputs/DscConfigurationAssociationPropertyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.automation.kotlin.inputs

import com.pulumi.azurenative.automation.inputs.DscConfigurationAssociationPropertyArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The Dsc configuration property associated with the entity.
 * @property name Gets or sets the name of the Dsc configuration.
 */
public data class DscConfigurationAssociationPropertyArgs(
    public val name: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.automation.inputs.DscConfigurationAssociationPropertyArgs> {
    override fun toJava():
        com.pulumi.azurenative.automation.inputs.DscConfigurationAssociationPropertyArgs =
        com.pulumi.azurenative.automation.inputs.DscConfigurationAssociationPropertyArgs.builder()
            .name(name?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DscConfigurationAssociationPropertyArgs].
 */
@PulumiTagMarker
public class DscConfigurationAssociationPropertyArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    /**
     * @param value Gets or sets the name of the Dsc configuration.
     */
    @JvmName("drigkeiffltrnhqy")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Gets or sets the name of the Dsc configuration.
     */
    @JvmName("rkqyrrcacsjqgyem")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): DscConfigurationAssociationPropertyArgs =
        DscConfigurationAssociationPropertyArgs(
            name = name,
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/automation/kotlin/inputs/DscConfigurationAssociationPropertyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.automation.kotlin.inputs

import com.pulumi.azurenative.automation.inputs.DscConfigurationAssociationPropertyArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The Dsc configuration property associated with the entity.
 * @property name Gets or sets the name of the Dsc configuration.
 */
public data class DscConfigurationAssociationPropertyArgs(
    public val name: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.automation.inputs.DscConfigurationAssociationPropertyArgs> {
    override fun toJava():
        com.pulumi.azurenative.automation.inputs.DscConfigurationAssociationPropertyArgs =
        com.pulumi.azurenative.automation.inputs.DscConfigurationAssociationPropertyArgs.builder()
            .name(name?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DscConfigurationAssociationPropertyArgs].
 */
@PulumiTagMarker
public class DscConfigurationAssociationPropertyArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    /**
     * @param value Gets or sets the name of the Dsc configuration.
     */
    @JvmName("qtvcuuhcftkxdubq")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Gets or sets the name of the Dsc configuration.
     */
    @JvmName("cgqatsnxoylsuofy")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): DscConfigurationAssociationPropertyArgs =
        DscConfigurationAssociationPropertyArgs(
            name = name,
        )
}
